@@ -143,6 +143,14 @@ class Object():
 
         if self.__dict__.get("guid"):
             raise ValueError(f"This {self.__class__.__name__} has already been created")
+
+        strip_endpoints = [
+            "endpoint",
+            "guid",
+            "listing_endpoint",
+        ]
+        data = {x: self.__dict__[x] for x in self.__dict__ if (x not in strip_endpoints and not x.startswith('_'))}
+
         data= self._client._post(self.__class__.listing_endpoint, data=self.__dict__)
 
         self.__dict__.update(data)
